==> deepin-camera_6.5.5.tar.xz: BUILD/src/translations/deepin-camera_ms.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ms">
<context>
    <name>CMainWindow</name>
    <message>
        <source>Video recording is in progress. Close the window?</source>
        <translation>Rakaman video masih berlangsung. Mahu tutup tetingkap?</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation type="vanished">Buka folder</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Tetapan</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Tiada</translation>
    </message>
    <message>
        <source>Photo</source>
        <translation>Foto</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>Video</translation>
    </message>
    <message>
        <source>Switch Cameras</source>
        <translation>Tukar Kamera</translation>
    </message>
</context>
<context>
    <name>CloseDialog</name>
    <message>
        <source>Cancel</source>
        <translation>Batal</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Tutup</translation>
    </message>
</context>
<context>
    <name>ImageItem</name>
    <message>
        <source>Copy</source>
        <translation>Salin</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Padam</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>Buka folder</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Cetak</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>You don&apos;t have permission to operate this folder</source>
        <translation>Anda tiada keizinan mengendalikan folder ini</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Tutup</translation>
    </message>
    <message>
        <source>Invalid folder</source>
        <translation type="vanished">Folder tidak sah</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>Buka folder</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Tetapan</translation>
    </message>
    <message>
        <source>Basic</source>
        <translation>Asas</translation>
    </message>
    <message>
        <source>File location</source>
        <translation>Lokasi fail</translation>
    </message>
    <message>
        <source>Shoot</source>
        <translation>Syot</translation>
    </message>
    <message>
        <source>Burst mode</source>
        <translation>Mod ledak</translation>
    </message>
    <message>
        <source>Self-timer delay</source>
        <translation>Lengah swa-pemasa</translation>
    </message>
    <message>
        <source>Output</source>
        <translation>Output</translation>
    </message>
    <message>
        <source>Output format</source>
        <translation>Format output</translation>
    </message>
    <message>
        <source>4 pcs</source>
        <translation>4 kpg</translation>
    </message>
    <message>
        <source>10 pcs</source>
        <translation>10 kpg</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Tiada</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>Kamera</translation>
    </message>
    <message>
        <source>Camera is an image and video capture utility using your PC camera or webcam.</source>
        <translation>Kamera ialah sebuah utiliti tangkapan imej dan video menggunakan kamera PC atau kamera sesawang anda.</translation>
    </message>
    <message>
        <source>File not saved</source>
        <translation>Fail tidak disimpan</translation>
    </message>
    <message>
        <source>Save to:</source>
        <translation type="vanished">Simpan ke:</translation>
    </message>
    <message>
        <source>Photo:</source>
        <translation>Foto:</translation>
    </message>
    <message>
        <source>Video:</source>
        <translation>Video:</translation>
    </message>
    <message>
        <source>Resolution settings</source>
        <translation>Tetapan resolusi</translation>
    </message>
    <message>
        <source>Resolution:</source>
        <translation type="vanished">Resolusi:</translation>
    </message>
    <message>
        <source>Photos:</source>
        <translation>Foto:</translation>
    </message>
    <message>
        <source>Videos:</source>
        <translation>Video:</translation>
    </message>
    <message>
        <source>Sound effects</source>
        <translation>Kesan bunyi</translation>
    </message>
    <message>
        <source>Mirror mode</source>
        <translation>Mod cermin</translation>
    </message>
    <message>
        <source>Flashlight</source>
        <translation>Lampu Denyar</translation>
    </message>
    <message>
        <source>Gridlines</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>1*1 lines</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>2*2 lines</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Maximum resolution:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Camera</source>
        <translation>Kamera</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Tetapan</translation>
    </message>
    <message>
        <source>Stop recording</source>
        <translation>Henti rakaman</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Salin</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Padam</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Buka</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Cetak</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Bantuan</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Pintasan paparan</translation>
    </message>
    <message>
        <source>Stop taking photos</source>
        <translation>Henti menangkap foto</translation>
    </message>
    <message>
        <source>Context menu</source>
        <translation>Menu konteks</translation>
    </message>
</context>
<context>
    <name>ThumbnailsBar</name>
    <message>
        <source>Take photo</source>
        <translation type="vanished">Tangkap foto</translation>
    </message>
    <message>
        <source>Record video</source>
        <translation type="vanished">Rakam video</translation>
    </message>
    <message>
        <source>Stop taking photos</source>
        <translation type="vanished">Henti menangkap foto</translation>
    </message>
</context>
<context>
    <name>dc::Settings</name>
    <message>
        <source>None</source>
        <translation>Tiada</translation>
    </message>
</context>
<context>
    <name>filterPreviewButton</name>
    <message>
        <source>Normal</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Vivid</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Warm</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cold</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Retro</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Film</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Gray</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>B&amp;W</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>takePhotoSettingAreaWidget</name>
    <message>
        <source>Flashlight</source>
        <translation>Lampu denyar</translation>
    </message>
    <message>
        <source>On</source>
        <translation>Hidup</translation>
    </message>
    <message>
        <source>Off</source>
        <translation>Mati</translation>
    </message>
    <message>
        <source>Delay capture</source>
        <translation>Lengah tangkapan</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Tiada</translation>
    </message>
    <message>
        <source>Filters</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Exposure</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>videowidget</name>
    <message>
        <source>No webcam found</source>
        <translation>Tiada kamera sesawang ditemui</translation>
    </message>
    <message>
        <source>The webcam is in use</source>
        <translation>Kamera sesawang sedang digunakan</translation>
    </message>
    <message>
        <source>Stop recording</source>
        <translation type="vanished">Henti rakaman</translation>
    </message>
</context>
</TS>

==> deepin-camera_6.5.20.tar.xz: BUILD/src/translations/deepin-camera_ms.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ms">
<context>
    <name>CMainWindow</name>
    <message>
        <source>Video recording is in progress. Close the window?</source>
        <translation>Rakaman video masih berlangsung. Mahu tutup tetingkap?</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation type="vanished">Buka folder</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Tetapan</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Tiada</translation>
    </message>
    <message>
        <source>Photo</source>
        <translation>Foto</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>Video</translation>
    </message>
    <message>
        <source>Switch Cameras</source>
        <translation>Tukar Kamera</translation>
    </message>
</context>
<context>
    <name>CloseDialog</name>
    <message>
        <source>Cancel</source>
        <translation>Batal</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Tutup</translation>
    </message>
</context>
<context>
    <name>ImageItem</name>
    <message>
        <source>Copy</source>
        <translation>Salin</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Padam</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>Buka folder</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Cetak</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>You don&apos;t have permission to operate this folder</source>
        <translation>Anda tiada keizinan mengendalikan folder ini</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Tutup</translation>
    </message>
    <message>
        <source>Invalid folder</source>
        <translation type="vanished">Folder tidak sah</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>Buka folder</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Tetapan</translation>
    </message>
    <message>
        <source>Basic</source>
        <translation>Asas</translation>
    </message>
    <message>
        <source>File location</source>
        <translation>Lokasi fail</translation>
    </message>
    <message>
        <source>Shoot</source>
        <translation>Syot</translation>
    </message>
    <message>
        <source>Burst mode</source>
        <translation>Mod ledak</translation>
    </message>
    <message>
        <source>Self-timer delay</source>
        <translation>Lengah swa-pemasa</translation>
    </message>
    <message>
        <source>Output</source>
        <translation>Output</translation>
    </message>
    <message>
        <source>Output format</source>
        <translation>Format output</translation>
    </message>
    <message>
        <source>4 pcs</source>
        <translation>4 kpg</translation>
    </message>
    <message>
        <source>10 pcs</source>
        <translation>10 kpg</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Tiada</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>Kamera</translation>
    </message>
    <message>
        <source>Camera is an image and video capture utility using your PC camera or webcam.</source>
        <translation>Kamera ialah sebuah utiliti tangkapan imej dan video menggunakan kamera PC atau kamera sesawang anda.</translation>
    </message>
    <message>
        <source>File not saved</source>
        <translation>Fail tidak disimpan</translation>
    </message>
    <message>
        <source>Save to:</source>
        <translation type="vanished">Simpan ke:</translation>
    </message>
    <message>
        <source>Photo:</source>
        <translation>Foto:</translation>
    </message>
    <message>
        <source>Video:</source>
        <translation>Video:</translation>
    </message>
    <message>
        <source>Resolution settings</source>
        <translation>Tetapan resolusi</translation>
    </message>
    <message>
        <source>Resolution:</source>
        <translation type="vanished">Resolusi:</translation>
    </message>
    <message>
        <source>Photos:</source>
        <translation>Foto:</translation>
    </message>
    <message>
        <source>Videos:</source>
        <translation>Video:</translation>
    </message>
    <message>
        <source>Sound effects</source>
        <translation>Kesan bunyi</translation>
    </message>
    <message>
        <source>Mirror mode</source>
        <translation>Mod cermin</translation>
    </message>
    <message>
        <source>Flashlight</source>
        <translation>Lampu Denyar</translation>
    </message>
    <message>
        <source>Gridlines</source>
        <translation>Garisan grid</translation>
    </message>
    <message>
        <source>1*1 lines</source>
        <translation>Garisan 1*1</translation>
    </message>
    <message>
        <source>2*2 lines</source>
        <translation>Garisan 2*2</translation>
    </message>
    <message>
        <source>Maximum resolution:</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Camera</source>
        <translation>Kamera</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Tetapan</translation>
    </message>
    <message>
        <source>Stop recording</source>
        <translation>Henti rakaman</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Salin</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Padam</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Buka</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Cetak</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Bantuan</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Pintasan paparan</translation>
    </message>
    <message>
        <source>Stop taking photos</source>
        <translation>Henti menangkap foto</translation>
    </message>
    <message>
        <source>Context menu</source>
        <translation>Menu konteks</translation>
    </message>
</context>
<context>
    <name>ThumbnailsBar</name>
    <message>
        <source>Take photo</source>
        <translation type="vanished">Tangkap foto</translation>
    </message>
    <message>
        <source>Record video</source>
        <translation type="vanished">Rakam video</translation>
    </message>
    <message>
        <source>Stop taking photos</source>
        <translation type="vanished">Henti menangkap foto</translation>
    </message>
</context>
<context>
    <name>dc::Settings</name>
    <message>
        <source>None</source>
        <translation>Tiada</translation>
    </message>
</context>
<context>
    <name>filterPreviewButton</name>
    <message>
        <source>Normal</source>
        <translation>Biasa</translation>
    </message>
    <message>
        <source>Vivid</source>
        <translation>Terang</translation>
    </message>
    <message>
        <source>Warm</source>
        <translation>Panas</translation>
    </message>
    <message>
        <source>Cold</source>
        <translation>Sejuk</translation>
    </message>
    <message>
        <source>Retro</source>
        <translation>Retro</translation>
    </message>
    <message>
        <source>Film</source>
        <translation>Filem</translation>
    </message>
    <message>
        <source>Gray</source>
        <translation>Kelabu</translation>
    </message>
    <message>
        <source>B&amp;W</source>
        <translation>H&amp;P</translation>
    </message>
</context>
<context>
    <name>takePhotoSettingAreaWidget</name>
    <message>
        <source>Flashlight</source>
        <translation>Lampu denyar</translation>
    </message>
    <message>
        <source>On</source>
        <translation>Hidup</translation>
    </message>
    <message>
        <source>Off</source>
        <translation>Mati</translation>
    </message>
    <message>
        <source>Delay capture</source>
        <translation>Lengah tangkapan</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Tiada</translation>
    </message>
    <message>
        <source>Filters</source>
        <translation>Penapis</translation>
    </message>
    <message>
        <source>Exposure</source>
        <translation>Dedahan</translation>
    </message>
</context>
<context>
    <name>videowidget</name>
    <message>
        <source>No webcam found</source>
        <translation>Tiada kamera sesawang ditemui</translation>
    </message>
    <message>
        <source>The webcam is in use</source>
        <translation>Kamera sesawang sedang digunakan</translation>
    </message>
    <message>
        <source>Stop recording</source>
        <translation type="vanished">Henti rakaman</translation>
    </message>
</context>
</TS>
